"""Object-specific python package to run automated tasks in the Chase Lab."""

from .ffsync import ffsync
from .ffconcat import ffconcat
from .lazytrim import lazytrim
from .improve_dlc_output import improve_dlc_output

from .version import __version__, VERSION
